spannertools.SlurSpanner
========================

.. abjad-lineage:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner

.. autoclass:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.override
   :noindex:

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.set
   :noindex:

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.start_offset
   :noindex:

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.storage_format
   :noindex:

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.timespan
   :noindex:

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.written_duration
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.direction
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.clear
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.pop_left
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__call__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__ge__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__gt__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__le__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner.__repr__
   :noindex:
